OpenTracing
===========

**This module is available only if you have opentracing installed**

trace_future
------------

.. autofunction:: satella.opentracing.trace_future

trace_function
--------------

.. autofunction:: satella.opentracing.trace_function

trace_exception
---------------

.. autofunction:: satella.opentracing.trace_exception

set_maximum_traceback_length
----------------------------

.. autofunction:: satella.opentracing.set_maximum_traceback_length
